summaryrefslogtreecommitdiffstats
path: root/policy/com
diff options
context:
space:
mode:
authorAndroid (Google) Code Review <android-gerrit@google.com>2009-12-03 11:00:06 -0800
committerAndroid (Google) Code Review <android-gerrit@google.com>2009-12-03 11:00:06 -0800
commitef469c337a6785f6ff92fb4a597faeea9c95097c (patch)
tree83f7a4f6cf3288d2a02e744947e70f67a65a6bd8 /policy/com
parent15620ce4151f88f70b05219669058f242df8bbab (diff)
parentce27776887fb252e08667c16e6945c7fecf33368 (diff)
downloadframeworks_base-ef469c337a6785f6ff92fb4a597faeea9c95097c.zip
frameworks_base-ef469c337a6785f6ff92fb4a597faeea9c95097c.tar.gz
frameworks_base-ef469c337a6785f6ff92fb4a597faeea9c95097c.tar.bz2
Merge change I85572973 into eclair
* changes: Do not show keyguard if screen is turned off by proximity sensor.
Diffstat (limited to 'policy/com')
-rw-r--r--policy/com/android/internal/policy/impl/KeyguardViewMediator.java7
1 files changed, 5 insertions, 2 deletions
diff --git a/policy/com/android/internal/policy/impl/KeyguardViewMediator.java b/policy/com/android/internal/policy/impl/KeyguardViewMediator.java
index 6b9db60..8d71146 100644
--- a/policy/com/android/internal/policy/impl/KeyguardViewMediator.java
+++ b/policy/com/android/internal/policy/impl/KeyguardViewMediator.java
@@ -280,8 +280,9 @@ public class KeyguardViewMediator implements KeyguardViewCallback,
/**
* Called to let us know the screen was turned off.
* @param why either {@link WindowManagerPolicy#OFF_BECAUSE_OF_USER} or
* {@link WindowManagerPolicy#OFF_BECAUSE_OF_TIMEOUT}.
*/
public void onScreenTurnedOff(int why) {
synchronized (this) {
@@ -312,6 +313,8 @@ public class KeyguardViewMediator implements KeyguardViewCallback,
sender);
if (DEBUG) Log.d(TAG, "setting alarm to turn off keyguard, seq = "
+ mDelayedShowingSequence);
+ } else if (why == WindowManagerPolicy.OFF_BECAUSE_OF_PROX_SENSOR) {
+ // Do not enable the keyguard if the prox sensor forced the screen off.
} else {
doKeyguard();
}
@@ -280,8 +280,9 @@ public class KeyguardViewMediator implements KeyguardViewCallback,
/**
* Called to let us know the screen was turned off.
- * @param why either {@link WindowManagerPolicy#OFF_BECAUSE_OF_USER} or
- * {@link WindowManagerPolicy#OFF_BECAUSE_OF_TIMEOUT}.
+ * @param why either {@link WindowManagerPolicy#OFF_BECAUSE_OF_USER},
+ * {@link WindowManagerPolicy#OFF_BECAUSE_OF_TIMEOUT} or
+ * {@link WindowManagerPolicy#OFF_BECAUSE_OF_PROX_SENSOR}.
*/
public void onScreenTurnedOff(int why) {